@@ -13,10 +13,19 @@
 "surveys_sample"
 
 
-#' Colors of German parties
+#' Colors for German parties
 #'
 #' A vector of colors associated with German parties.
 #'
 #' @format A named character vector. Names indicate parties. Values contain
 #' color strings for the respective parties
 "party_colors_de"
+
+
+#' Labels for German parties
+#'
+#' A vector of labels associated with German parties.
+#'
+#' @format A named character vector. Names indicate parties. Values contain
+#'   party names suitable for plot labels.
+"party_labels_de"
